@@ -357,7 +357,6 @@ isMac <- function() {
   !need
 }
 
-
 # This is directly from tools::file_ext_sans_ext
 filePathSansExt <- function(x) {
   sub("([^.]+)\\.[[:alnum:]]+$", "\\1", x)
@@ -383,45 +382,6 @@ isDirectory <- function(pathnames) {
   id
 }
 
-
-isAbsolutePath <- function(pathnames) {
-  # modified slightly from R.utils::isAbsolutePath
-  keep <- is.character(pathnames)
-  if (isFALSE(keep)) stop("pathnames must be character")
-  nPathnames <- length(pathnames)
-  if (nPathnames == 0L) {
-    return(logical(0L))
-  }
-  done <- logical(nPathnames)
-  nas <- is.na(pathnames)
-  if (all(nas)) {
-    return(!nas)
-  }
-
-  tildas <- startsWith(pathnames[!nas], "~")
-  if (any(tildas)) {
-    done[!nas][tildas] <- TRUE
-  }
-
-  if (all(tildas)) {
-    return(done)
-  }
-
-  colon <- regexpr("^.:(/|\\\\)", pathnames[!nas][!tildas])
-  hasColon <- colon != -1L
-  if (any(hasColon)) {
-    done[!nas][!tildas][hasColon] <- TRUE
-  }
-  if (all(hasColon)) {
-    return(done)
-  }
-  curPaths <- pathnames[!nas][!tildas][!hasColon]
-  done[!nas][!tildas][!hasColon] <- startsWith(curPaths, "/") | startsWith(curPaths, "\\")
-  names(done) <- pathnames
-  return(done)
-}
-
-
 isFile <- function(pathnames) {
   keep <- is.character(pathnames)
   if (isFALSE(keep)) stop("pathnames must be character")
@@ -433,39 +393,9 @@ isFile <- function(pathnames) {
   iF
 }
 
-isAbsolutePath <- function(pathnames) {
-  # modified slightly from R.utils::isAbsolutePath
-  keep <- is.character(pathnames)
-  if (isFALSE(keep)) stop("pathnames must be character")
-  origPn <- pathnames
-  nPathnames <- length(pathnames)
-  if (nPathnames == 0L) {
-    return(logical(0L))
-  }
-  if (nPathnames > 1L) {
-    res <- sapply(pathnames, FUN = isAbsolutePath)
-    return(res)
-  }
-  if (is.na(pathnames)) {
-    return(FALSE)
-  }
-  if (regexpr("^~", pathnames) != -1L) {
-    return(TRUE)
-  }
-  if (regexpr("^.:(/|\\\\)", pathnames) != -1L) {
-    return(TRUE)
-  }
-  components <- strsplit(pathnames, split = "[/\\]")[[1L]]
-  if (length(components) == 0L) {
-    return(FALSE)
-  }
-  (components[1L] == "")
-}
-
 # This is so that we don't need to import from backports
 isFALSE <- function(x) is.logical(x) && length(x) == 1L && !is.na(x) && !x
 
-
 #' Use `message` with a consistent use of `verbose`
 #'
 #' This family has a consistent use of `verbose` allowing messages to be
@@ -580,8 +510,6 @@ messageColoured <- function(..., colour = NULL,
   }
 }
 
-
-
 methodFormals <- function(fun, signature = character(), envir = parent.frame()) {
   if (is.character(fun)) {
     fun <- get(fun, mode = "function", envir = envir)
@@ -601,7 +529,6 @@ methodFormals <- function(fun, signature = character(), envir = parent.frame())
   genFormals
 }
 
-
 .fileExtsKnown <- function() {
   if (requireNamespace("sf", quietly = TRUE) && requireNamespace("DBI", quietly = TRUE)) {
     shpFile <- getOption("reproducible.shapefileRead", "sf::st_read")
@@ -646,14 +573,11 @@ methodFormals <- function(fun, signature = character(), envir = parent.frame())
   df
 }
 
-
 #' @importFrom utils packageDescription
 .isDevelVersion <- function() {
   length(strsplit(packageDescription("reproducible")$Version, "\\.")[[1]]) > 3
 }
 
-
-
 #' A helper to `getOption("reproducible.rasterRead")`
 #'
 #' A helper to `getOption("reproducible.rasterRead")`
@@ -668,7 +592,6 @@ rasterRead <- function(...) {
   eval(parse(text = getOption("reproducible.rasterRead")))(...)
 }
 
-
 rasterType <- function(nlayers = 1,
                        rasterRead = getOption("reproducible.rasterRead", "terra::rast")) {
   if (is.character(rasterRead)) {
@@ -686,7 +609,6 @@ rasterType <- function(nlayers = 1,
   rasterRead
 }
 
-
 vectorType <- function(vectorRead = getOption("reproducible.shapefileRead", "sf::st_read")) {
   needRasterPkg <- FALSE
   vectorReadSubs <- substitute(vectorRead)
@@ -719,7 +641,6 @@ vectorType <- function(vectorRead = getOption("reproducible.shapefileRead", "sf:
   vectorRead
 }
 
-
 #' Set seed with a random value using Sys.time()
 #'
 #' This will set a random seed.
@@ -785,7 +706,8 @@ layerNamesDelimiter <- "_%%_"
 #' @name internetExists
 #' @rdname internetExists
 internetExists <- function() {
-  urlExists("https://CRAN.R-project.org")
+  # urlExists("https://CRAN.R-project.org")
+  urlExists("https://www.google.com")
 }
 
 #' @rdname internetExists
